import java.util.HashSet;
import java.util.Iterator;

/**
 * For serializing and deserializing sets of simple string.
 *
 * @author Max Barkley <mbarkley@redhat.com>
 */
public class SerializableSet extends HashSet {

	private static final long serialVersionUID = -4968825975745239833L;
	public static final String delimeter = ",";

	/**
	 * @return The serialized {@link String} representation of this set. Note that
	 *         ',' is used to separate values, but values are <b>not</b> escaped.
	 */
	public String serialize() {
		final StringBuilder builder = new StringBuilder();
		final Iterator<String> iterator = iterator();
		if (iterator.hasNext())
			builder.append(iterator.next());
		while (iterator.hasNext()) {
			builder.append(delimeter).append(iterator.next());
		}
		return builder.toString();
	}

	/**
	 * Deserialize the given {@link String} into a new {@link SerializableSet}.
	 *
	 * @param serialized
	 *            A {@link String} generated by a call to
	 *            {@link SerializableSet#serialize() serialize}.
	 * @return A new {@link SerializableSet}.
	 */
	public SerializableSet deserialize(final String serialized) {
		SerializableSet set = new SerializableSet();
		final String[] items = serialized.replaceAll("\\[|\\]", "").split(delimeter);
		for (int i = 0; i < items.length; i++) {
			if (!items[i].equals(""))
				set.add(items[i].trim());
		}
		return set;
	}

}
